@@ -3,4 +3,4 @@
 
 Find it here https://resummino.hepforge.org/.
 """
-from .run import run, set_path, get_path
+from .run import run, set_path, get_path, default_resummino_runner
